/* Main Header */
$main-header-background-color: var(--main-header-background-color);
$main-header-menu-hover-background-color: var(--main-header-menu-hover-background-color);
$main-header-menu-active-background-color: var(--main-header-menu-active-background-color);
$main-header-menu-background-color: var(--main-header-menu-background-color);
$main-header-dropdown-hover-background-color: var(--main-header-dropdown-hover-background-color);
$main-header-dropdown-active-background-color: var(--main-header-dropdown-active-background-color);
$main-header-border-color: var(--main-header-border-color);
$main-header-dropdown-background-color: var(--main-header-dropdown-background-color);
$main-header-dropdown-item-color: var(--main-header-dropdown-item-color);
$main-header-dropdown-item-hover-background-color: var(--main-header-dropdown-item-hover-background-color);
$main-header-dropdown-item-avatar-background-color: var(--main-header-dropdown-item-avatar-background-color);
$main-header-dropdown-private-vault-color: var(--main-header-dropdown-private-vault-color);
$main-header-menu-button-notification-color: #ff1a1a;
$main-header-menu-button-icon-color: var(--main-header-menu-button-icon-color);
$main-header-topbar-button-bg-hover-color: var(--main-header-topbar-button-bg-hover-color);
$main-header-topbar-button-bg-pressed-color: var(--main-header-topbar-button-bg-pressed-color);
$floating-action-button-add-bg-color: #61aa30;
$floating-action-button-add-hover-bg-color: #508b27;
$floating-action-button-add-pressed-bg-color: #3e6d1f;
$floating-action-button-delete-bg-color: #f20000;
$floating-action-button-delete-hover-bg-color: #cb0000;
$floating-action-button-delete-pressed-bg-color: #a30000;
$floating-action-button-refresh-bg-color: #3aa3ff;
$floating-action-button-refresh-hover-bg-color: #0087fe;
$floating-action-button-refresh-pressed-bg-color: #0068c3;

/* Side Menu */
$menu-background-color: var(--menu-background-color);
$menu-text-color: var(--menu-text-color);
$menu-text-active-color: var(--menu-text-active-color);
$menu-text-active-background-color: var(--menu-text-active-background-color);
$menu-text-hover-background-color: var(--menu-text-hover-background-color);
$menu-text-focus-background-color: var(--menu-text-focus-background-color);
$menu-separator-color: var(--menu-separator-color);
$menu-right-border-color: var(--menu-right-border-color);
$menu-version-color: var(--menu-version-color);

/*Side panel */
$side-panel-background-color: var(--side-panel-background-color);
$side-panel-title-color: var(--side-panel-title-color);
$side-panel-search-border-color: var(--side-panel-search-border-color);
$side-panel-search-border-hover-color: var(--side-panel-search-border-hover-color);
$side-panel-text-color: var(--side-panel-text-color);
$side-panel-search-box-shadow: var(--side-panel-search-box-shadow);
$side-panel-search-active-clear: var(--side-panel-search-active-clear);
$side-panel-search-inactive-clear: var(--side-panel-search-inactive-clear);
$side-panel-border-color: var(--side-panel-border-color);
$side-panel-recent-hover-bg-color: var(--side-panel-recent-hover-bg-color);
$side-panel-select-btn-inactive-bg-color: var(--side-panel-select-btn-inactive-bg-color);
$side-panel-select-btn-inactive-color: var(--side-panel-select-btn-inactive-color);
$side-panel-select-btn-inactive-hover-bg-color: var(--side-panel-select-btn-inactive-hover-bg-color);
$side-panel-link-hover-bg-color: var(--side-panel-link-hover-bg-color);
$side-panel-close-icon-color: var(--side-panel-close-icon-color);
$side-panel-btn-bg-color: var(--side-panel-btn-bg-color);
$side-panel-btn-text-color: var(--side-panel-btn-text-color);

/* Dialogs */
$dialog-bg-color: var(--dialog-bg-color);
$dialog-secondary-bg-color: var(--dialog-secondary-bg-color);
$dialog-footer-bg-color: var(--dialog-footer-bg-color);
$dialog-header-txt-color: var(--dialog-header-txt-color);
$dialog-header-border-color: var(--dialog-header-border-color);
$dialog-footer-border-color: var(--dialog-header-border-color);
$dialog-footer-txt-color: var(--dialog-footer-txt-color);
$dialog-footer-btn-bg-color: var(--dialog-footer-btn-bg-color);
$dialog-footer-btn-bg-hover-color: var(--dialog-footer-btn-bg-hover-color);
$dialog-footer-btn-bg-pressed-color: var(--dialog-footer-btn-bg-pressed-color);
$entry-selector-txt-color: var(--entry-selector-txt-color);
$entry-selector-item-shadow-color: var(--entry-selector-item-shadow-color);
$dialog-border-color: var(--dialog-border-color);
$dialog-menu-selected-bg-color: var(--dialog-menu-selected-bg-color);
$dialog-menu-selected-border-color: var(--dialog-menu-selected-border-color);
$dialog-menu-selected-txt-color: var(--dialog-menu-selected-txt-color);
$tabview-inactive-bg-color: var(--tabview-inactive-bg-color);
$tabview-active-bg-color: var(--tabview-active-bg-color);
$tabview-active-txt-color: var(--tabview-active-txt-color);

/* Buttons */
$action-btn-icon-color: var(--action-btn-icon-color);
$action-btn-hover-bg-color: var(--action-btn-hover-bg-color);
$action-btn-pressed-bg-color: var(--action-btn-pressed-bg-color);
$action-btn-secondary-icon-color: var(--action-btn-secondary-icon-color);
$action-btn-secondary-hover-bg-color: var(--action-btn-secondary-hover-bg-color);
$action-btn-secondary-pressed-bg-color: var(--action-btn-secondary-pressed-bg-color);
$action-btn-icon-delete-hover-color: var(--action-btn-icon-delete-hover-color);
$action-btn-overview-icon-hover-bg-color: var(--action-btn-overview-icon-hover-bg-color);
$action-btn-add-icon-color: var(--action-btn-add-icon-color);
$action-btn-add-hover-bg-color: var(--action-btn-add-hover-bg-color);
$action-btn-add-pressed-bg-color: var(--action-btn-add-pressed-bg-color);
$default-btn-bg-color: var(--default-btn-bg-color);
$default-btn-bg-hover-color: var(--default-btn-bg-hover-color);
$default-btn-bg-pressed-color: var(--default-btn-bg-pressed-color);
$default-btn-text-color: var(--default-btn-text-color);
$default-btn-link-text-color: var(--default-btn-link-text-color);
$default-btn-link-text-color-darker: var(--default-btn-link-text-color-darker);
$action-btn-default-icon-color: var(--action-btn-default-icon-color);
$action-btn-default-icon-hover-color: var(--action-btn-default-icon-hover-color);
$select-btn-txt-color: var(--select-btn-txt-color);
$error-btn-bg-color: var(--error-btn-bg-color);
$error-btn-bg-hover-color: var(--error-btn-bg-hover-color);
$error-btn-bg-pressed-color: var(--error-btn-bg-pressed-color);



$action-btn-outline-primary-color: var(--action-btn-outline-primary-color);
$action-btn-outline-primary-bg-color: var(--action-btn-outline-primary-bg-color);
$action-btn-outline-primary-bg-hover-color: var(--action-btn-outline-primary-bg-hover-color);
$action-btn-outline-primary-bg-pressed-color: var(--action-btn-outline-primary-bg-pressed-color);
$action-btn-outline-primary-border-color: var(--action-btn-outline-primary-border-color);
$action-btn-outline-primary-border-hover-color: var(--action-btn-outline-primary-border-hover-color);
$action-btn-outline-primary-border-pressed-color: var(--action-btn-outline-primary-border-pressed-color);

$action-btn-outline-secondary-color: var(--action-btn-outline-secondary-color);
$action-btn-outline-secondary-bg-color: var(--action-btn-outline-secondary-bg-color);
$action-btn-outline-secondary-bg-hover-color: var(--action-btn-outline-secondary-bg-hover-color);
$action-btn-outline-secondary-bg-pressed-color: var(--action-btn-outline-secondary-bg-pressed-color);
$action-btn-outline-secondary-border-color: var(--action-btn-outline-secondary-border-color);
$action-btn-outline-secondary-border-hover-color: var(--action-btn-outline-secondary-border-hover-color);
$action-btn-outline-secondary-border-pressed-color: var(--action-btn-outline-secondary-border-pressed-color);

$action-btn-outline-tertiary-color: var(--action-btn-outline-tertiary-color);
$action-btn-outline-tertiary-bg-color: var(--action-btn-outline-tertiary-bg-color);
$action-btn-outline-tertiary-bg-hover-color: var(--action-btn-outline-tertiary-bg-hover-color);
$action-btn-outline-tertiary-bg-pressed-color: var(--action-btn-outline-tertiary-bg-pressed-color);
$action-btn-outline-tertiary-border-color: var(--action-btn-outline-tertiary-border-color);
$action-btn-outline-tertiary-border-hover-color: var(--action-btn-outline-tertiary-border-hover-color);
$action-btn-outline-tertiary-border-pressed-color: var(--action-btn-outline-tertiary-border-pressed-color);

$error-btn-outline-primary-color: var(--error-btn-outline-primary-color);
$error-btn-outline-primary-pressed-color: var(--error-btn-outline-primary-pressed-color);
$error-btn-outline-primary-bg-color: var(--error-btn-outline-primary-bg-color);
$error-btn-outline-primary-bg-hover-color: var(--error-btn-outline-primary-bg-hover-color);
$error-btn-outline-primary-bg-pressed-color: var(--error-btn-outline-primary-bg-pressed-color);
$error-btn-outline-primary-border-color: var(--error-btn-outline-primary-border-color);
$error-btn-outline-primary-border-hover-color: var(--error-btn-outline-primary-border-hover-color);
$error-btn-outline-primary-border-pressed-color: var(--error-btn-outline-primary-border-pressed-color);

$error-btn-outline-secondary-color: var(--error-btn-outline-secondary-color);
$error-btn-outline-secondary-pressed-color: var(--error-btn-outline-secondary-pressed-color);
$error-btn-outline-secondary-bg-color: var(--error-btn-outline-secondary-bg-color);
$error-btn-outline-secondary-bg-hover-color: var(--error-btn-outline-secondary-bg-hover-color);
$error-btn-outline-secondary-bg-pressed-color: var(--error-btn-outline-secondary-bg-pressed-color);
$error-btn-outline-secondary-border-color: var(--error-btn-outline-secondary-border-color);
$error-btn-outline-secondary-border-hover-color: var(--error-btn-outline-secondary-border-hover-color);
$error-btn-outline-secondary-border-pressed-color: var(--error-btn-outline-secondary-border-pressed-color);

$error-btn-outline-tertiary-color: var(--error-btn-outline-tertiary-color);
$error-btn-outline-tertiary-pressed-color: var(--error-btn-outline-tertiary-pressed-color);
$error-btn-outline-tertiary-bg-color: var(--error-btn-outline-tertiary-bg-color);
$error-btn-outline-tertiary-bg-hover-color: var(--error-btn-outline-tertiary-bg-hover-color);
$error-btn-outline-tertiary-bg-pressed-color: var(--error-btn-outline-tertiary-bg-pressed-color);
$error-btn-outline-tertiary-border-color: var(--error-btn-outline-tertiary-border-color);
$error-btn-outline-tertiary-border-hover-color: var(--error-btn-outline-tertiary-border-hover-color);
$error-btn-outline-tertiary-border-pressed-color: var(--error-btn-outline-tertiary-border-pressed-color);

$btn-outline-disabled-color: var(--btn-outline-disabled-color);
$btn-outline-disabled-bg-color: var(--btn-outline-disabled-bg-color);
$btn-outline-disabled-border-color: var(--btn-outline-disabled-border-color);

$neo-input-readonly-bg: var(--neo-input-readonly-bg); // FIXME: This should be darker WHEN our background is properly #1c1c1c instead of 292929
$neo-input-warning-bg: var(--neo-input-warning-bg);
$neo-input-danger-bg: var(--neo-input-danger-bg);

$neo-input-warning-fg: var(--neo-input-warning-fg);
$neo-input-danger-fg: var(--neo-input-danger-fg);



/* ScrollBar */
$scrollbar-color: var(--scrollbar-color);
$scrollbar-background-color: var(--scrollbar-background-color);

/* Data View */
$dataview-header-bg-color: var(--dataview-header-bg-color);
$dataview-border-color: var(--dataview-border-color);
$dataview-text-color: var(--dataview-text-color);
$dataview-bg-color: var(--dataview-bg-color);
$dataview-bg-hover-color: var(--dataview-bg-hover-color);
$dataview-close-icon-color: var(--dataview-close-icon-color);
$dataview-close-icon-hover-bg-color: var(--dataview-close-icon-hover-bg-color);

/* Container */
$entry-container-bg-color: var(--entry-container-bg-color);
$entry-container-overview-bg-color: var(--entry-container-overview-bg-color);
$dashboard-header-bg-color: var(--dashboard-header-bg-color);
$dashboard-data-border-color: var(--dashboard-data-border-color);
$dashboard-data-title-color: var(--dashboard-data-title-color);
$dashboard-data-main-title-color: var(--dashboard-data-main-title-color);
$dashboard-data-subtitle-color: var(--dashboard-data-subtitle-color);
$dashboard-data-text-color: var(--dashboard-data-text-color);
$layout-wrapper-bg-color: var(--layout-wrapper-bg-color);
$dashboard-card-bg-color: var(--dashboard-card-bg-color);
$dashboard-card-secondary-bg-color: var(--dashboard-card-secondary-bg-color);
$dashboard-card-border-color: var(--dashboard-card-border-color);
$dashboard-card-txt-color: var(--dashboard-card-txt-color);
$dashboard-card-subtitle-color: var(--dashboard-card-subtitle-color);
$dashboard-card-title-color: var(--dashboard-card-title-color);
$dashboard-card-list-bg-color: var(--dashboard-card-list-bg-color);
$dashboard-card-list-bg-hover-color: var(--dashboard-card-list-bg-hover-color);
$dashboard-card-list-border-color: var(--dashboard-card-list-border-color);
$dashboard-card-icon-color: var(--dashboard-card-icon-color);
$dashboard-card-default-icon-color: var(--dashboard-card-default-icon-color);
$dashboard-card-empty-icon-color: var(--dashboard-card-empty-icon-color);
$info-card-background-color: var(--info-card-background-color);
$overlay-panel-bg-color: var(--overlay-panel-bg-color);
$overlay-panel-border-color: var(--overlay-panel-border-color);
$page-header-bg-color: var(--page-header-bg-color);
$layout-container-bg-color: var(--layout-container-bg-color);
$layout-container-admin-border-color: var(--layout-container-admin-border-color);
$layout-container-admin-shadow-color: var(--layout-container-admin-shadow-color);
$steps-container-bg-color: var(--steps-container-bg-color);
$admin-item-bg-color: var(--admin-item-bg-color);
$admin-item-bg-hover-color: var(--admin-item-bg-hover-color);
$admin-item-bg-active-color: var(--admin-item-bg-active-color);
$admin-text-icon-color: var(--admin-text-icon-color);
$admin-text-icon-hover-color: var(--admin-text-icon-hover-color);
$admin-text-hover-color: var(--admin-text-hover-color);
$admin-separator-color: var(--admin-separator-color);
$admin-separator-header-color: var(--admin-separator-header-color);
$admin-separator-title-color: var(--admin-separator-title-color-color);
$overlay-mask-color: var(--overlay-mask-color);

/* Tree */
$tree-selector-bg-color: var(--tree-selector-bg-color);
$tree-selector-border-color: var(--tree-selector-border-color);
$tree-selector-text-color: var(--tree-selector-text-color);
$tree-selector-text-highlight-color: var(--tree-selector-text-highlight-color);
$tree-item-selected-bg-color: var(--tree-item-selected-bg-color);
$tree-item-hover-bg-color: var(--tree-item-hover-bg-color);
$tree-search-input-bg-color: var(--tree-search-input-bg-color);
$tree-search-btn-border-color: var(--tree-search-btn-border-color);

/* Inputs */
$input-txt-border-hover-color: var(--input-txt-border-hover-color);
$input-txt-border-focus-color: var(--input-txt-border-focus-color);
$input-txt-bg-color: var(--input-txt-bg-color);
$input-txt-bg-disabled-color: var(--input-txt-bg-disabled-color);
$input-txt-border-disabled-color: var(--input-txt-border-disabled-color);
$input-txt-color: var(--input-txt-color);
$input-txt-border-color: var(--input-txt-border-color);
$input-txt-shadow-color: var(--input-txt-shadow-color);
$input-txt-success-color: var(--input-txt-success-color);
$input-txt-error-color: var(--input-txt-error-color);
$input-switch-default-bg-color: var(--input-switch-default-bg-color);
$input-switch-active-bg-color: var(--input-switch-active-bg-color);
$input-switch-active-hover-bg-color: var(--input-switch-active-hover-bg-color);
$dropdown-container-bg-color: var(--dropdown-container-bg-color);
$dropdown-bg-color: var(--dropdown-bg-color);
$dropdown-trigger-color: var(--dropdown-trigger-color);
$dropdown-filter-icon-color: var(--dropdown-filter-icon-color);
$input-default-border-color: var(--input-default-border-color);
$input-default-border-hover-color: var(--input-default-border-hover-color);
$dropdown-item-selected-bg-color: var(--dropdown-item-selected-bg-color);
$dropdown-item-bg-color: var(--dropdown-item-bg-color);
$dropdown-item-selected-txt-color: var(--dropdown-item-selected-txt-color);
$dropdown-item-selected-bg-hover-color: var(--dropdown-item-selected-bg-hover-color);
$dropdown-item-txt-color: var(--dropdown-item-txt-color);
$dropdown-user-group-selected-bg-hover-color: var(--dropdown-user-group-selected-bg-hover-color);
$dropdown-filter-container-separator-color: var(--dropdown-filter-container-separator-color);
$paginator-active-bg-color: var(--paginator-active-bg-color);
$input-txt-border-error-color: var(--input-txt-border-error-color);
$dropdown-overlay-border-color: var(--dropdown-overlay-border-color);
$input-txt-sensitive-color: #eb7800;
$input-txt-highlight-color: #FFEB3B;
$input-txt-placeholder: var(--input-txt-placeholder);

/* Chips */
$input-chips-bg-color: var(--input-chips-bg-color);
$input-chips-bg-hover-color: var(--input-chips-bg-hover-color);
$input-chips-bg-pressed-color: var(--input-chips-bg-pressed-color);
$input-chips-txt-color: var(--input-chips-txt-color);
$input-chips-txt-hover-color: var(--input-chips-txt-hover-color);
$input-chips-icon-color: var(--input-chips-icon-color);

/* Labels */
$default-text-color: var(--default-text-color);
$default-text-theme-color: #424242;
$admin-title-color: var(--admin-title-color);
$admin-header-color: var(--admin-header-color);
$disabled-text-color: var(--disabled-text-color);
$hint-text-color: var(--hint-text-color);
$secondary-text-color: var(--secondary-text-color);
$form-text-color: var(--form-text-color);
$active-tab-text-color: var(--active-tab-text-color);
$menu-panel-txt-color: var(--menu-panel-txt-color);
$lighter-default-text-color: var(--lighter-default-text-color);
$default-header-documentation-color: var(--default-header-documentation-color);
$secondary-label-text-color: var(--secondary-label-text-color);

/* Grids */
$grid-header-title-txt-color: var(--grid-header-title-txt-color);
$grid-main-row-bg-color: var(--grid-main-row-bg-color);
$grid-child-row-bg-color: var(--grid-child-row-bg-color);
$grid-disabled-row-bg-color: var(--grid-disabled-row-bg-color);
$grid-disabled-txt-color: var(--grid-disabled-txt-color);
$grid-item-border-color: var(--grid-item-border-color);
$grid-icon-color: var(--grid-icon-color);
$grid-icon-hover-color: var(--grid-icon-hover-color-color);
$grid-row-hover-bg-color: var(--grid-row-hover-bg-color);
$grid-txt-color: var(--grid-txt-color);
$grid-container-bg-color: var(--grid-container-bg-color);

/* Messages */
$messageFontColor: var(--message-font-color);
$infoMessageBackgroundColor: var(--info-message-background-color);
$infoMessageBorderColor: var(--info-message-border-color);
$successMessageBackgroundColor: var(--success-message-background-color);
$successMessageBorderColor: var(--success-message-border-color);
$warningMessageBackgroundColor: var(--warning-message-background-color);
$warningMessageBorderColor: var(--warning-message-border-color);
$statusMessageBackgroundColor: var(--status-message-background-color);
$statusMessageBorderColor: var(--status-message-border-color);
$errorMessageBackgroundColor: var(--error-message-background-color);
$errorMessageBorderColor: var(--error-message-border-color);
$checkoutRequestIconNeutralColor: #000000B3;

/* Data Breach */
$infoDataBreachVerificationIconColor: var(--info-data-breach-verification-icon-color);
$successDataBreachSuccessIconColor: var(--success-data-breach-verification-icon-color);
$failedDataBreachVerificationIconColor: var(--failed-data-breach-verification-icon-color);

/* Background */
$overlay-bg-color: var(--overlay-bg-color);

/* Horizontal Line */
$horizontal-line-color: var(--horizontal-line-color);

/* DropZone */
$dropzone-bg-color: var(--dropzone-bg-color);
$dropzone-border-color: var(--dropzone-border-color);
$dropzone-icon-color: var(--dropzone-icon-color);
$dropzone-text-color: var(--dropzone-text-color);
$dropzone-border-dragover-color: var(--dropzone-border-dragover-color);
$dropzone-icon-dragover-color: var(--dropzone-icon-dragover-color);
$dropzone-text-dragover-color: var(--dropzone-text-dragover-color);
$dropzone-bg-file-uploaded-color: var(--dropzone-bg-file-uploaded-color);
$dropzone-border-file-uploaded-color: var(--dropzone-border-file-uploaded-color);

/* Tooltip */
$tooltip-bg-color: var(--tooltip-bg-color);
$tooltip-txt-color: var(--tooltip-txt-color);
$tooltip-box-shadow-color: var(--tooltip-box-shadow-color);

/* Connection Type */
$default-connection-type-color: #0087f2;
$group-connection-type-color: #ebb450;
$credential-connection-type-color: #eb7800;

/*Markdown */
$code-bg-color: var(--code-bg-color);
$pre-bg-color: var(--pre-bg-color);

/* TabView */
$tab-view-hover-color: var(--tab-view-hover-color);

/* License */
$default-product-license-color: #0087fe;

/* Loader */
$default-loader-color: var(--action-btn-secondary-icon-color);
$blue-loader-color: var(--action-btn-icon-color);

/* User Tags */
$user-tag-external-color: var(--user-tag-external-color);
$user-tag-external-bg-color: var(--user-tag-external-bg-color);
$user-tag-privileged-color: var(--user-tag-privileged-color);
$user-tag-privileged-bg-color: var(--user-tag-privileged-bg-color);

