@use '../style/mixins' as *;
@use '../style/variables' as *;
@use '../theme/theme-mode-variables' as *;


.p-inputgroup {

  .p-action-button {
    border-radius: 0;
    border-right: none;
    border-top: 1px solid $input-txt-border-color;
    border-bottom: 1px solid $input-txt-border-color;
    min-width: 2.15em;
    margin: 0;
    background-color: transparent !important;
    transition: transform 100ms ease-out;

    .dvl-icon {
      font-size: 20px;
    }

    &.stay-pressed, &:hover:not(.p-disabled):not([disabled]) {
      color: $action-btn-icon-color;
    }

    &:active:not(.p-disabled):not([disabled]) {
      color: $action-btn-icon-color;
    }

    @include media-breakpoint-down(sm) {
      min-width: 2.15em;

      .dvl-icon {
        font-size: 20px;
      }
    }
  }

  sd-action-button .p-action-button {
    height: 100%;
    background: $input-txt-bg-color;
    color: $form-text-color;
    border: none;
  }

  sd-basic-copy-clipboard {
    background: $input-txt-bg-color;

    hub-container-actions-loader {
      height: 100%;
      display: flex;
      align-items: center;

      i {
        font-size: 15px !important;
      }
    }
  }

  sd-action-button {
    .p-button {
      border-radius: 0;
    }

    &:last-child .p-button {
      border-radius: 0 ($borderRadius - 2) ($borderRadius - 2) 0 !important;
    }
  }

  &:not(.filter-input-group) > *:last-child .p-button:not(.p-button-default),
  &:not(.filter-input-group) > .p-button:not(.p-button-default):last-child {
    border-radius: 0 ($borderRadius - 2) ($borderRadius - 2) 0 !important;
  }
}

.p-action-button-group sd-action-button:not(:last-child) .p-action-button{
  margin-right: 10px;
}
