:root,
.force-light-theme {
  --base-black-rgb: 0, 0, 0; // #000
  --base-accent-rgb: 0, 104, 195; // #0068c3
  --base-white-rgb: 255, 255, 255; // #fff
  --base-color-rgb: var(--base-black-rgb);
  --base-color-inverted-rgb: var(--base-white-rgb);
  --dvls-logo: 237, 31, 36;

  --title-color: rgba(var(--base-color-rgb), 0.8);

  --neutral-inverted-color: #ffffff;

  --base-border-rgb: var(--base-black-rgb);
  --base-background-color: var(--base-white-rgb);

  --accent-color: rgb(var(--base-accent-rgb));

  --entry-layout-horizontal-padding: 10px;

  --btn-icon-color: rgba(var(--base-color-rgb), 0.8);

  --entry-status-color: rgba(var(--base-color-rgb), 0.6); // Default
  --entry-status-background-opacity: 1;
  --entry-status-by-me-color-rgb: 97, 170, 48;
  --entry-status-by-others-color-rgb: 255, 26, 26;
  --entry-status-flag-expired-color-rgb: var(--entry-status-by-others-color-rgb);
  --entry-status-flag-archived-color-rgb: 139, 69, 19;
  --entry-status-flag-warning-color-rgb: 0, 104, 195;
  --entry-status-flag-broken-color-rgb: 245, 208, 0;
  --entry-status-flag-locked-color-rgb: 255, 130, 0;
  --entry-status-flag-disabled-color-rgb: 153, 153, 153;

  --status-banner-info-color-rgb: 0, 104, 195;
  --status-banner-warning-color-rgb: 240, 201, 9;
  --status-banner-success-color-rgb: 97, 170, 48;
  --status-banner-disabled-color-rgb: 184, 184, 184;
  --status-banner-error-color-rgb: 255, 26, 26;
  --status-banner-background-opacity: 0.25;
  --status-banner-background-opacity-lighter: 0.1;
  --status-warning-bg-color: rgba(
    var(--status-banner-warning-color-rgb),
    var(--status-banner-background-opacity-lighter)
  );

  // Borders
  --border-secondary-color: #0000001f;
  --background-secondary-color: rgba(var(--base-background-color), 1);
  --border-color-primary: rgba(var(--base-color-rgb), 0.3);
  --border-color-secondary: rgba(var(--base-color-rgb), 0.12);
  --border-color-tertiary: rgba(var(--base-color-rgb), 0.7);
  --border-base-100: rgba(242, 242, 242, 1);
  --border-radius: 4px;

  // loader
  --loader-background-color: rgba(var(--base-background-color), 1);
  --loader-logo-color: rgba(var(--dvls-logo), 0.4);
  --loader-spinner-color: rgba(var(--dvls-logo));

  //Dialog
  --dialog-header-background-color: #fff;
  --dialog-footer-background-color: #f5f5f5;
  --dialog-header-text-color: var(--title-color);
  --dialog-header-icon-text-color: var(--title-color);
  --dialog-menu-background-color: #fff;
  --dialog-menu-text-color: #424242;
  --dialog-menu-highlight-text-color: #424242;
  --dialog-menu-highlight-background-color: #f5f5f5;
  --dialog-menu-highlight-border-color: #bdbdbd;
  --dialog-content-background-color: #fff;
  --dialog-border-color: rgba(0, 104, 195, 0.1);
  --dialog-menu-border-color: #f5f5f5;
  --dialog-footer-default-button-background-color: #0068c3;
  --dialog-footer-delete-button-background-color: #ff1a1a;
  --dialog-footer-default-button-text-color: #fff;
  --dialog-footer-delete-button-background-hover-color: #de0000;
  --dialog-footer-default-button-background-hover-color: #00539c;
  --dialog-footer-cancel-button-text-color: #424242;
  --dialog-footer-disabled-button-background-hover-color: #bdbdbd;
  --dialog-entry-background-color: #f5f5f5;
  --dialog-header-confirmation-background-color: #f1f1f1;

  /* Container */
  --entry-container-bg-color: #f5f5f5;
  --entry-container-overview-bg-color: #fff;
  --layout-container-bg-color: #fff;
  --layout-container-admin-border-color: #fff;
  --layout-container-admin-shadow-color: #e8e8e8;

  /* Subset box */
  --subset-box-bg-color: rgba(240, 246, 251, 0.6);
  --add-subset-button-border-color: #00000012;
  --add-subset-button-text-color: rgba(0, 0, 0, 0.6);
  --add-subset-button-small-text-color: rgba(0, 0, 0, 0.4);

  //Main Toolbar
  --main-toolbar-text-color: #fff;
  --main-toolbar-background-color: #fff;
  --main-toolbar-icon-text-color: #0068c3;
  --main-toolbar-icon-color: #fff;
  --main-toolbar-border-color: #e8e8e8;
  --vault-selector-color: #fff;
  --vault-selector-icon-color: #616161;
  --repo-selector-background: #f5f5f5;
  --header-element-hover-background: #00539c;
  --header-element-active-background: #004f99;
  --repo-selector-search-background: #fff;
  --repo-element-hover-background: #f5f5f5;
  --repo-element-active-background: #f5f5f5;
  --repo-avatar-active-background: #c8c8c8;
  --header-border-bottom-color: #bdbdbd;

  //Admin section
  --breadcrumb-text-color: #424242;
  --admin-background-section-color: #fff;
  --admin-section-icon-bg-color: #f5f5f5;
  --admin-section-bg-hover-color: rgba(58, 163, 255, 0.2);
  --admin-section-bg-active-color: rgba(58, 163, 255, 0.4);
  --admin-text-icon-color: #0068c3;
  --admin-text-icon-hover-color: #fff;
  --admin-section-separator-color: #e0e0e0;
  --admin-section-header-separator-color: #eee;
  --admin-section-item-label-color: #424242;
  --admin-section-item-label-hover-color: #212121;

  //Main Breadcrumb
  --main-breadcrumb-text-color: #424242;
  --main-breadcrumb-background-color: #fff;
  --main-breadcrumb-arrow-icon-color: #0068c3;
  --main-breadcrumb-folder-icon-color: #0068c3;

  //Treenode Section
  --tree-item-highlight-color: #e7f4ff;
  --tree-item-focus-color: #f5f5f5;
  --main-tree-item-highlight-color: #e7f4ff;
  --tree-item-hover-color: #f5f5f5;
  --tree-item-context-menu-hover-color: #f5f5f5;
  --tree-selector-text-highlight-color: #000;

  //Labels
  --label-input-color: #616161;
  --label-default-color: #424242;
  --label-title-color: #0068c3;
  --label-link-color: #0068c3;
  --label-title-input: #0068c3;
  --label-subtitle-color: #9e9e9e;
  --label-version-color: #bdbdbd;
  --label-treenode-color: #424242;
  --label-disabled-color: #bdbdbd;
  --label-readonly-color: #898996;

  //Icons
  --icon-default-color: #424242;
  --icon-hover-color: #0068c3;
  --icon-color: #1f85eb;
  --search-filter-color: #424242;

  //Hotkeys
  --hotkeys-border-color: #d7d7d7;
  --hotkeys-text-color: #424242;
  --hotkeys-background-color: #f5f5f5;

  //Inputs
  --input-border-color: var(--border-200);
  --input-background-color: var(--bg-input);
  --input-shadow: #e5f0f9;
  --input-hover-border-color: var(--accent-brand-400);
  --input-text-color: var(--text-400);
  --input-placeholder-color: rgba(0, 0, 0, 0.4);

  --input-disabled-background-color: #f5f5f5;

  // Multiselect
  --multiselect-background-color: var(--bg-input);
  --multiselect-border-color: var(--border-200);
  --multiselect-hover-border-color: var(--accent-brand-400);
  --multiselect-text-color: var(--text-400);

  --input-icon-color: var(--base-color-rgb);

  --input-accent-color: rgb(var(--base-accent-rgb));
  --input-label-color: var(--label-default-color);
  --input-selected-indicator-color: rgb(var(--base-white-rgb));

  --input-disabled-border-color: rgba(var(--base-border-rgb), 0.1);
  --input-disabled-label-color: rgba(var(--base-border-rgb), 0.3);
  --input-disabled-selected-indicator-color: rgba(var(--base-border-rgb), 0.3);

  --input-radio-checkbox-border-color: rgba(
    var(--base-border-rgb),
    0.3
  ); // Needs to avoid conflict with exisitng --input-border-color
  --input-radio-checkbox-disabled-background-color: rgba(
    var(--base-border-rgb),
    0.03
  ); // Needs to avoid conflict with exisitng --input-disabled-background-color
  --input-radio-checkbox-box-shadow: 0 0px 0 3px rgba(var(--base-accent-rgb), 0.2);

  --dropdown-item-separator-color: #424242;
  --dropdown-item-highlight-background-color: #e5f0f9;
  --dropdown-item-highlight-text-color: #0068c3;
  --dropdown-item-background-color: #fff;
  --dropdown-item-hover-background-color: #f5f5f5;
  --dropdown-background-color: var(--p-select-background);
  --inputSwitch-active-background-color: #0068c3;
  --inputSwitch-inactive-background-color: #a9a9a9;
  --password-strenght-border-color: #e8e8e8;
  --drag-drop-item-background-color: aliceblue;
  --steps-border-color: #c8c8c8;
  --search-border-color: #b2d1ed;
  --search-border-active-color: #66a4db;
  --search-border-shadow-color: #e5f0f9;
  --search-button-clear-color: #e1e1e1;
  --search-input-color: transparent;
  --cancel-button-footer-border: rgba(0, 0, 0, 0.15);
  --cancel-button-footer-border-hover: rgba(0, 104, 195, 0.12);

  //Menus
  --main-menu-background-color: #1e1f24;
  --main-menu-item-message-border-color: #1a77c9;
  --main-menu-item-hover-background-color: rgba(255, 255, 255, 0.1);
  --main-menu-item-active-background-color: rgba(255, 255, 255, 0.15);
  --main-menu-item-active-color: #fff;
  --main-menu-item-color: rgba(255, 255, 255, 0.8);
  --main-menu-text-color: #484848;
  --menu-card-background-color: #fff;
  --menu-card-pam-background-color: #f5f5f5;
  --menu-pam-card-background-color: #fff;
  --menu-pam-card-spinner-background-color: rgba(255, 255, 255, 0.75);
  --menu-pam-card-border-color: #e0e0e0;
  --menu-selected-card-background-color: #c3e3ff;
  --menu-pam-card-hover-color: rgb(230, 230, 230);
  --menu-pam-empty-text-color: #cfd1d0;
  --main-menu-border-color: #e0e0e0;
  --card-txt-color: #424242;

  //Panel Menu
  --panel-menu-separator-color: #424242;
  --panel-menu-highlight-background-color: #e5f0f9;
  --panel-menu-highlight-text-color: #0068c3;
  --panel-menu-background-color: #fff;
  --panel-menu-hover-background-color: #f5f5f5;

  //Connection View
  --connection-sidebar-background-color: #f7fbff;
  --connection-view-default-background-color: #ffffff;
  --connection-view-wrapper-background-color: #f2f7fc;
  --connection-view-border-color: #e8e8e8;
  --connection-view-text-color: #424242;
  --connection-view-link-color: #0068c3;
  --connection-view-title-color: #0068c3;
  --connection-view-quote-color: #f8f8f8;
  --dashboard-background-color: #f5f5f5;

  --dashboard-data-subtitle-color: #9e9e9e;
  --dashboard-data-text-color: #757575;

  //Table
  --table-column-title-color: #0068c3;
  --table-column-title-background-hover-color: #f8f8f8;
  --table-column-title-background-color: #fff;
  --table-row-text-color: #424242;
  --table-row-background-color: #fff;
  --table-child-row-background-color: #f3f6f9;
  --table-border-color: #e8e8e8;
  --table-title-border-color: #a6c9e2;
  --table-link-color: #0068c3;
  --table-granted-bg-color: #dcffe5;
  --table-header-color: #fff;

  //Overview
  --overview-background-color: rgb(var(--base-background-color));
  --overview-border-color: #e8e8e8;

  //Account divider
  --divider-border-color: #e8e8e8;

  //Messages
  --message-error-icon-color: #cb091f;
  --message-error-color: #ff1a1a;
  --message-error-background-color: #ffa8a8;
  --message-info-color: #fff;
  --message-info-background-color: #38a2ff;
  --message-warn-color: #bd8c09;
  --message-warn-background-color: #f3db9b;
  --message-success-color: #196b0f;
  --message-success-background-color: #b7d8b7;
  --message-font-color: #000000;
  --message-font-opacity: 70%;
  --message-box-shadow: 0 8px 8px 0 rgba(0, 0, 0, 0.16);
  --message-high-priority-background-color: #ffe8e8;
  --message-high-priority-color: #ff1a1a;

  --info-message-background-color: #afdaff;
  --success-message-background-color: #caecb4;
  --warning-message-background-color: #fff5c0;
  --error-message-background-color: #ffb7b7;

  //Scheduling report
  --scheduling-datetime-color: #fff;
  --scheduling-title-color: whitesmoke;
  --scheduling-border-color: #ddd;
  --scheduling-today-color: #fcf8e3;
  --scheduling-today-text-color: #424242;
  --scheduling-hover-item-background-color: #e3f3ff;

  //Buttons
  --button-action-background-hover-color: #ebf3fa;
  --button-action-text-hover-color: #0068c3;
  --button-action-text-active-color: #00539c;
  --button-action-text-color: #0068c3;
  --button-action-secondary-icon-color: #424242;
  --button-action-secondary-hover-bg-color: #ebebeb;
  --button-action-secondary-pressed-bg-color: #dbdbdb;
  --button-action-secondary-background: #f0f6fb;
  --button-action-icon-delete-hover-color: #ff1a1a;
  --button-action-add-icon-color: #61aa30;
  --button-action-add-hover-bg-color: #ebf9d5;
  --button-action-add-pressed-bg-color: #caecb4;
  --button-action-icon-color: #0068c3;
  --button-action-hover-bg-color: #ebf3fa;
  --button-action-pressed-bg-color: #dbeaf7;
  --button-add-shadow-color: #999;
  --button-floating-background-hover: #508b27;
  --button-divider-color: #e8e8e8;

  --button-primary-text: #ffffff;
  --button-primary-border: #0068c3;
  --button-primary-fill: #0068c3;

  --button-primary-hover-text: #ffffff;
  --button-primary-hover-border: #0051b2;
  --button-primary-hover-fill: #0051b2;

  --button-primary-pressed-fill: #003ca2;

  --button-primary-danger-text: #ff1a1a;
  --button-primary-danger-border: rgba(255, 26, 26, 0.25);
  --button-primary-danger-fill: #fff3f3;

  --button-primary-danger-hover-fill: #ffdbdb;
  --button-primary-danger-pressed-fill: #b90000;

  --button-secondary-text: var(--text-brand);
  --button-secondary-border: rgba(var(--base-accent-rgb), 0.15);
  --button-secondary-fill: var(--bg-brand-200);

  --button-secondary-hover-fill: #dfecf7;
  --button-secondary-hover-border: var(--accent-brand-200);
  --button-secondary-hover-text: var(--text-brand);

  --button-secondary-pressed-fill: var(--accent-brand-400);
  --button-secondary-pressed-border: var(--accent-brand-400);
  --button-secondary-pressed-text: #ffffff;

  --button-secondary-danger-text: #ff1a1a;
  --button-secondary-danger-border: rgba(255, 26, 26, 0.25);

  --button-secondary-danger-fill: #fff3f3;
  --button-secondary-danger-hover-fill: #ffdbdb;
  --button-secondary-danger-pressed-fill: #b90000;

  --button-tertiary-fill: #ffffff;
  --button-tertiary-border: var(--border-200);
  --button-tertiary-text: var(--text-brand);

  --button-tertiary-hover-fill: #e0edf8;
  --button-tertiary-hover-border: var(--accent-brand-200);

  --button-tertiary-pressed-fill: #cce1f3;
  --button-tertiary-pressed-border: var(--accent-brand-200);

  --button-tertiary-danger-text: #ff1a1a;
  --button-tertiary-danger-border: rgba(255, 26, 26, 0.15);
  --button-tertiary-danger-fill: #ffffff;

  --button-tertiary-danger-hover-fill: #ffdbdb;
  --button-tertiary-danger-hover-border: rgba(255, 26, 26, 0.15);

  --button-tertiary-danger-pressed-text: #ffffff;
  --button-tertiary-danger-pressed-fill: #ff1a1a;

  --button-disabled-fill: rgba(0, 0, 0, 0.05);
  --button-disabled-border: rgba(0, 0, 0, 0.1);
  --button-disabled-text: rgba(0, 0, 0, 0.3);

  --field-border-width: 1px;

  //Overlay Panel
  --overlay-panel-background-color: #fff;
  --overlay-panel-text-color: #424242;
  --overlay-panel-splitter-color: #f5f5f5;

  //SidePanel
  --side-panel-text-color: #424242;
  --side-panel-background-color: #ffffff;
  --side-panel-border-color: #0068c34d;
  --side-panel-title-color: #424242;

  //Messages
  --dataview-text-color: #424242;
  --dataview-border-color: #e8e8e8;
  --dataview-bg-hover-color: #eee;
  --secondary-text-color: #ffffff;
  --lighter-default-text-color: #999999;
  --unread-message-border-color: #0068c3;
  --unread-message-hover-border-color: #b2b2b2;
  --unread-message-background-color: #f0f8ff;

  //Scrollbar
  --scrollbar-color: rgba(0, 0, 0, 0.3);
  --scrollbar-background-color: transparent;

  //Fieldset
  --fieldset-title-color: #0068c3;
  --fieldset-sub-title-color: rgba(0, 0, 0, 0.6);
  --fieldset-border-color: #cce1f3;

  //Administration Dashboard
  --admin-item-border-color: #fff;
  --admin-item-icon-color: #0068c3;
  --admin-item-text-color: #0068c3;
  --admin-item-shadow-color: #e8e8e8;

  //Drag-and-drop
  --droparea-border-color: #88c8ff;
  --droparea-border-color-hover: #0068c3;
  --droparea-border-color-uploaded: #dcdcdc;
  --droparea-background-color: #f2f7fc;
  --droparea-delete-icon-color: #616161;
  --droparea-delete-icon-color-hover: #0068c3;
  --droparea-filesize-color: #616161;
  --droparea-filename-color: #212121;
  --droparea-upload-icon-color: #60a1d9;
  --droparea-upload-icon-color-hover: #0068c3;
  --droparea-upload-font-color: #616161;
  --droparea-upload-font-color-hover: #212121;
  --droparea-background-color-uploaded: #f5f5f5;
  --droparea-dragenter-background-color: #dbeaf7;

  //Chips
  --chips-token-background-color: #eeeeee;
  --chips-token-font-color: #212121;

  //Autocomplete
  --autocomplete-item-font-color: #212121;
  --autocomplete-panel-background-color: #ffffff;
  --autocomplete-item-hover-color: #f5f5f5;
  --autocomplete-panel-box-shadow: 0 3px 6px 0 #e5f0f9;

  // Security Severity Level
  --severity-level-critical-color: #ffeeee;
  --severity-level-critical-bg: #c80000;
  --severity-level-high-color: #c80000;
  --severity-level-high-bg: #ffeeee;
  --severity-level-medium-color: #e2a300;
  --severity-level-medium-bg: #f4f1e9;
  --severity-level-low-color: #006400;
  --severity-level-low-bg: #e6ece6;
  --security-box-title: #000;
  --security-box-bg: #f5f5f5;
  --security-box-action-bg: #dceaf7;
  --security-box-action-color: #0068c3;
  --security-box-border-color: #ededed;
  --security-chart-progress: #00cf00;
  --security-chart-remaining: #bfbfbf;

  // Checkout
  --approver-bg-color: rgba(0, 0, 0, 0.04);

  // User tags
  --user-tags-background-color-external: rgba(161, 184, 7, 0.15);
  --user-tags-text-color-external: rgba(161, 184, 7, 1);
  --user-tags-background-color-privileged: rgba(238, 187, 7, 0.15);
  --user-tags-text-color-privileged: rgba(188, 148, 6, 1);
  --user-tags-background-color-contractor: rgba(0, 104, 195, 0.15);
  --user-tags-text-color-contractor: rgba(0, 104, 195, 1);

  // MeterGroup
  --metergroup-text-color: #424242;
  --metergroup-no-data-text-color: var(--text-100);
  --metergroucolor-danger: #fb9d9d;
  --metergroucolor-warn: #f6d623;
  --metergroucolor-safe: #b5fb9d;
  --metergroup-color-danger: #fb9d9d;
  --metergroup-color-warn: #f6d623;
  --metergroup-color-safe: #b5fb9d;
  --metergroup-background-color: rgba(var(--base-color-rgb), 0.15);
  --metergroup-outline-color: var(--neutral-inverted-color);

  //Purple
  --accent-purple-100: rgba(240,217,252,1);
  --accent-purple-200: rgba(226,173,255,1);
  --accent-purple-300: rgba(202,106,255,1);
  --accent-purple-400: rgba(153,0,238,1); // primary
  --accent-purple-500: rgba(108,0,168,1);
  --accent-purple-600: rgba(62,0,97,1);

  //Blue
  --blue-primary: #0068c3;
  --blue-900: #3aa3ff;
  --blue-800: #88c8ff;
  --blue-700: #afdaff;
  --blue-500: #d7ecff;
  --blue-300: #eaf5ff;

  --blue-primary-text-color: white;
  --blue-900-text-color: black;
  --blue-800-text-color: black;
  --blue-700-text-color: black;
  --blue-500-text-color: black;
  --blue-300-text-color: black;

  //Red
  --red-primary: #ff1a1a;
  --red-900: #ff6868;
  --red-800: #ff9090;
  --red-700: #ffb7b7;
  --red-500: #ffdede;
  --red-300: #fff2f2;
  --red-400: #f04438;

  --red-primary-text-color: white;
  --red-900-text-color: black;
  --red-800-text-color: black;
  --red-700-text-color: black;
  --red-500-text-color: black;
  --red-300-text-color: black;

  //Green
  --green-primary: #61aa30;
  --green-900: #7ecc49;
  --green-800: #9ed977;
  --green-700: #caecb4;
  --green-500: #ebf9d5;
  --green-300: #eaf7e2;

  --green-primary-text-color: black;
  --green-900-text-color: black;
  --green-800-text-color: black;
  --green-700-text-color: black;
  --green-500-text-color: black;
  --green-300-text-color: black;

  //Yellow
  --yellow-primary: #ffda23;
  --yellow-900: #ffe772;
  --yellow-800: #ffee99;
  --yellow-700: #fff5c0;
  --yellow-500: #fff8d4;
  --yellow-300: #fffeb7;

  --yellow-primary-text-color: black;
  --yellow-900-text-color: black;
  --yellow-800-text-color: black;
  --yellow-700-text-color: black;
  --yellow-500-text-color: black;
  --yellow-300-text-color: black;

  //Orange
  --orange-primary: #ff8200;
  --orange-900: #ff9f3b;
  --orange-800: #ffbc76;
  --orange-700: #ffcf9d;
  --orange-500: #ffecd8;
  --orange-300: #fff5eb;

  --orange-primary-text-color: black;
  --orange-900-text-color: black;
  --orange-800-text-color: black;
  --orange-700-text-color: black;
  --orange-500-text-color: black;
  --orange-300-text-color: black;

  //Grey
  --grey-primary: #000000;
  --grey-900: #212121;
  --grey-800: #424242;
  --grey-700: #616161;
  --grey-600: #757575;
  --grey-500: #9e9e9e;
  --grey-400: #bdbdbd;
  --grey-300: #e0e0e0;
  --grey-200: #eeeeee;
  --grey-100: #f5f5f5;
  --grey-0: #fafafa;

  --grey-primary-text-color: white;
  --grey-900-text-color: white;
  --grey-800-text-color: white;
  --grey-700-text-color: white;
  --grey-600-text-color: white;
  --grey-500-text-color: black;
  --grey-400-text-color: black;
  --grey-300-text-color: black;
  --grey-200-text-color: black;
  --grey-100-text-color: black;
  --grey-0-text-color: black;

  //Text
  --text-color-primary: rgba(0, 0, 0, 0.8);
  --text-color-secondary: rgba(0, 0, 0, 0.6);
  --text-color-tertiary: rgba(0, 0, 0, 0.4);

  --text-color-accent: rgba(0, 0, 0, 1);

  //Log event level
  --log-event-level-error: rgba(255, 26, 26, 1);
  --log-event-level-warning: rgba(255, 130, 0, 1);
  --log-event-level-information: rgba(0, 104, 195, 1);

  //swagger
  --swagger-caret-color-filter: brightness(100%);

  //font
  --font-open-sans: 'Open Sans Variable', sans-serif;
  --font-roboto: 'Roboto Variable', sans-serif;
  --font-monospace: 'Noto Sans Mono Variable', monospace;

  //input switch
  --input-switch-default-bg-color: #bdbdbd;
  --input-switch-active-bg-color: #0068c3;
  --input-switch-active-hover-bg-color: #00539c;
  --iframe-dialog-color: #ffffff;

  //Design System
  --border-search: #dcdcdc;
  --border-brand-100: rgba(var(--base-accent-rgb), 0.1);
  --border-brand-200: rgba(var(--base-accent-rgb), 0.15);
  --border-brand-300: rgba(var(--base-accent-rgb), 0.2);
  --border-brand-400: rgba(var(--base-accent-rgb), 0.35);
  --secondary-action-bg: #f0f6fb;
  --fill-base-200: #f2f2f2;
  --fill-brand-100: #fafcff;
  --fill-brand-200: #f1f8fe;
  --fill-brand-300: #eaf5ff;
  --fill-200: #f9f9f9;
  --fill-300: #f2f2f2;
  --fill-500: #e2e2e2;
  --box-fill: #ffffff;

  //Text
  --dropdown-border: #f2f2f2;
  --dropdown-fill: #ffffff;

  --spacing-0: 0;
  --spacing-1: 4px;
  --spacing-15: 6px;
  --spacing-2: 8px;
  --spacing-25: 10px;
  --spacing-3: 12px;
  --spacing-4: 16px;
}
