/********** Global import variables/mixins for css (so no need to reimport in all "...scss") **********/
@use 'style/mixins' as *;
@use 'style/variables' as *;
@use 'style/typography' as *;
@use 'theme/theme-mode-variables' as *;
@use 'theme/root-theme' as *;
@use 'theme/dark-theme' as *;
@use 'theme/light-theme' as *;
@use 'dvls-stack/variables.generated' as *;
@use 'dvls-stack/theme/light-theme' as *;
@use 'dvls-stack/theme/dark-theme' as *;
@use '@devolutions/web-active-directory-gui/assets/css/ad-styles' as *;
@use '../../client/app/styles/ad-theme-bridge.gateway' as *;

@use 'style/base' as *;
@use 'style/entry-status' as *;

/********** Overrides - Only Used Components **********/
/* Core Components */
@use 'override/_p-button' as *;
@use 'override/_p-button-action-button' as *;
@use 'override/_p-checkbox' as *;
@use 'override/_p-input' as *;
@use 'override/_p-input-switch' as *;
@use 'override/_p-inputgroup' as *;

/* Dropdowns & Selections */
@use 'override/_p-autocomplete' as *;
@use 'override/_p-dialog' as *;
@use 'override/_p-dropdown' as *;
@use 'override/_p-multiselect' as *;
@use 'override/_p-select' as *;

/* Navigation & Layout */
@use 'override/_p-tabview' as *;
@use 'override/_p-divider' as *;

/* Feedback Components */
@use 'override/_p-messages_p-toast' as *;
@use 'override/_p-progress-spinner' as *;
@use 'override/_p-tooltip' as *;

/* Miscellaneous */
@use 'override/_p-chips' as *;
@use 'override/_p-component-overlay' as *;
@use 'override/_p-slider' as *;

/********* Fonts imports ************/
@import url('https://cdnfonts.devolutions.net/OpenSans/variable-font/OpenSans.css');
@import url('https://cdnfonts.devolutions.net/Roboto/static/Roboto.css');


/* Devolutions icon font must always win */
.dvl-icon,
[class*="dvl-icon-"] {
  font-family: 'devolutions-icons' !important;
  font-style: normal;
  font-weight: normal;
  line-height: 1;
}

/* PrimeIcons must always win over generic PrimeNG font overrides. */
.pi,
[class^="pi-"],
[class*=" pi-"] {
  font-family: 'primeicons' !important;
  font-style: normal;
  font-weight: normal;
  line-height: 1;
}

.full-width-dropdown .p-dropdown,
.full-width-dropdown .p-select {
  width: 100%;
}

.debug {
  border: 1px solid red;
}
