@use '../style/mixins' as *;
@use '../style/variables' as *;
@use '../theme/theme-mode-variables' as *;

.button-spinner.p-progress-spinner {
  top: 3px;
  width: 16px;
  height: 16px;
}

.p-lightbox-content {
  background: transparent;
}

body .p-lightbox {
  box-shadow: none;
}
