.dark-theme {
  --base-accent-rgb: 58, 163, 255; // #3aa3ff
  --base-color-rgb: 255, 255, 255;
  --base-color-inverted-rgb: var(--base-black-rgb);
  --btn-icon-color: rgba(var(--base-color-rgb), .8);
  --base-border-rgb: var(--base-color-rgb);
  --borders-colors-brand-tertiary: rgba(58, 163, 255, 0.1);

  --title-color: rgba(var(--base-color-rgb), .8);

  --entry-status-background-opacity: .8;

  --status-info-banner-color-rgb: 58, 163, 255;
  --status-warning-banner-color-rgb: 251, 209, 0;
  --status-banner-pending-color-rgb: 255, 142, 38;
  --status-success-banner-color-rgb: 106, 185, 52;
  --status-disabled-banner-color-rgb: 224, 224, 224;
  --status-error-banner-color-rgb: 242, 0, 0;
  --status-banner-neutral-color-rgb: 255, 255, 255;
  --status-banner-background-opacity: .4;

  // Borders
  --border-splitter-color: #525252;

  /* Main Header */
  --main-header-background-color: #000;
  --main-header-menu-hover-background-color: #333;
  --main-header-menu-active-background-color: #525252;
  --main-header-menu-background-color: #1c1c1c;
  --main-header-dropdown-hover-background-color: #333;
  --main-header-dropdown-active-background-color: #525252;
  --main-header-border-color: #141414;
  --main-header-dropdown-background-color: #141414;
  --main-header-dropdown-item-color: #999;
  --main-header-dropdown-item-hover-background-color: #323232;
  --main-header-dropdown-item-avatar-background-color: #3d3d3d;
  --main-header-dropdown-private-vault-color: #757575;
  --main-header-menu-button-icon-color: #e0e0e0;
  --main-header-topbar-button-bg-hover-color: #333333;
  --main-header-topbar-button-bg-pressed-color: #525252;
  --main-header-topbar-admin-flag-bg-color: #0087fe;

  /* Side Menu */
  --menu-background-color: #1f1f1f;
  --menu-text-color: #e0e0e0;
  --menu-text-active-color: #3aa3ff;
  --menu-text-active-background-color: #143857;
  --menu-text-hover-background-color: #282828;
  --menu-text-focus-background-color: #3a3a3a;
  --menu-separator-color: #333;
  --menu-right-border-color: #141414;
  --menu-version-color: #525252;

  /* Side panel */
  --side-panel-background-color: #212121;
  --side-panel-title-color: #e0e0e0;
  --side-panel-search-border-color: #00539c;
  --side-panel-search-border-hover-color: #0068c3;
  --side-panel-text-color: #e0e0e0;
  --side-panel-search-box-shadow: #143857;
  --side-panel-search-active-clear: #3aa3ff;
  --side-panel-search-inactive-clear: #333333;
  --side-panel-border-color: #616161;
  --side-panel-recent-hover-bg-color: #323232;
  --side-panel-select-btn-inactive-bg-color: #616161;
  --side-panel-select-btn-inactive-color: #e0e0e0;
  --side-panel-select-btn-inactive-hover-bg-color: #353535;
  --side-panel-link-hover-bg-color: #353535;
  --side-panel-close-icon-color: #3aa3ff;
  --side-panel-btn-bg-color: #3aa3ff;
  --side-panel-btn-text-color: #fff;

  /* Status */
  --status-info-bg-color: rgba(var(--status-banner-info-color-rgb), var(--status-banner-background-opacity));
  --status-info-text-color: rgb(var(--status-banner-info-color-rgb));
  --status-success-bg-color: rgba(var(--status-banner-success-color-rgb), var(--status-banner-background-opacity));
  --status-success-bg-color-lighter: rgba(var(--status-banner-success-color-rgb), .1);
  --status-success-text-color: rgb(var(--status-banner-success-color-rgb));
  --status-warning-bg-color: rgba(var(--status-banner-warning-color-rgb), var(--status-banner-background-opacity));
  --status-warning-bg-color-lighter: rgba(var(--status-banner-warning-color-rgb), .1);
  --status-warning-text-color: rgb(var(--status-banner-warning-color-rgb));
  --status-pending-bg-color: rgba(var(--status-banner-pending-color-rgb), var(--status-banner-background-opacity));
  --status-pending-bg-color-lighter: rgba(var(--status-banner-pending-color-rgb), .1);
  --status-pending-text-color: rgb(var(--status-banner-pending-color-rgb));
  --status-error-bg-color: rgba(var(--status-banner-error-color-rgb), var(--status-banner-background-opacity));
  --status-error-bg-color-lighter: rgba(var(--status-banner-error-color-rgb), .1);
  --status-error-text-color: rgb(var(--status-banner-error-color-rgb));
  --status-neutral-bg-color: rgba(var(--status-banner-neutral-color-rgb), .05);
  --status-neutral-text-color: rgba(var(--status-banner-neutral-color-rgb), .4);

  /* Dialogs */
  --dialog-base-bg-color: rgba(26, 26, 26, 1);
  --dialog-bg-color: var(--dialog-base-bg-color, #1a1a1a);
  --dialog-secondary-bg-color: #3aa3ff;
  --dialog-footer-bg-color: #292929;
  --dialog-header-txt-color: var(--title-color);
  --dialog-header-border-color: var(--borders-colors-brand-tertiary, rgba(58, 163, 255, 0.10));
  --dialog-footer-txt-color: #999999;
  --dialog-footer-btn-bg-color: #3aa3ff;
  --dialog-footer-btn-bg-hover-color: #0087fe;
  --dialog-footer-btn-bg-pressed-color: #0068c3;
  --entry-selector-txt-color: #f5f5f5;
  --entry-selector-item-shadow-color: #3aa3ff;
  --dialog-border-color: #292929;
  --dialog-menu-selected-bg-color: #1f1f1f;
  --dialog-menu-selected-border-color: #333;
  --dialog-menu-selected-txt-color: #e0e0e0;
  --tabview-inactive-bg-color: #292929;
  --tabview-active-bg-color: #3aa3ff;
  --tabview-active-txt-color: #3aa3ff;
  --devolutions-send-icon-color: #afdaff;

  /* Buttons */
  --action-btn-icon-color: #3aa3ff;
  --action-btn-hover-bg-color: #00539c;
  --action-btn-pressed-bg-color: #003e75;
  --action-btn-secondary-icon-color: #999999;
  --action-btn-secondary-hover-bg-color: #3d3d3d;
  --action-btn-secondary-pressed-bg-color: #333333;
  --action-btn-add-icon-color: #6ab934;
  --action-btn-add-hover-bg-color: #3e6d1f;
  --action-btn-add-pressed-bg-color: #2d4e16;
  --action-btn-icon-delete-hover-color: #f20000;
  --action-btn-overview-icon-hover-bg-color: #194267;
  --default-btn-bg-color: #0068c3;
  --default-btn-bg-hover-color: #00539c;
  --default-btn-bg-pressed-color: #003e75;
  --default-btn-text-color: #fff;
  --default-btn-link-text-color: #3aa3ff;
  --default-btn-link-text-color-darker: #007eec;
  --action-btn-default-icon-color: #707070;
  --action-btn-default-icon-hover-color: #999999;
  --select-btn-txt-color: #fff;
  --error-btn-bg-color: #f20000;
  --error-btn-bg-hover-color: #cb0000;
  --error-btn-bg-pressed-color: #a30000;
  --action-btn-popup-hover-bg-color: #3d3d3d;
  --action-btn-popup-pressed-bg-color: #525252;
  --action-btn-delete-bg-color: #f20000;
  --action-btn-delete-bg-hover-color: #cb0000;
  --action-btn-delete-bg-pressed-color: #a30000;
  --action-btn-outline-primary-color: #fff;
  --action-btn-outline-primary-bg-color: #3aa3ff;
  --action-btn-outline-primary-bg-hover-color: #298dff;
  --action-btn-outline-primary-bg-pressed-color: #1a79ff;
  --action-btn-outline-primary-border-color: #3aa3ff;
  --action-btn-outline-primary-border-hover-color: #298dff;
  --action-btn-outline-primary-border-pressed-color: #1a79ff;

  --action-btn-outline-secondary-color: #3aa3ff;
  --action-btn-outline-secondary-bg-color: #151a1e;
  --action-btn-outline-secondary-bg-hover-color: #0b0c0d;
  --action-btn-outline-secondary-bg-pressed-color: rgba(var(--base-accent-rgb), 0.14);
  --action-btn-outline-secondary-border-color: rgba(var(--base-accent-rgb), 0.25);
  --action-btn-outline-secondary-border-hover-color: rgba(var(--base-accent-rgb), 0.25);
  --action-btn-outline-secondary-border-pressed-color: rgba(var(--base-accent-rgb), 0.25);

  --action-btn-outline-tertiary-color: #3aa3ff;
  --action-btn-outline-tertiary-bg-color: var(--base-color-rgb);
  --action-btn-outline-tertiary-bg-hover-color: #162028;
  --action-btn-outline-tertiary-bg-pressed-color: #000000;
  --action-btn-outline-tertiary-border-color: rgba(var(--base-accent-rgb), 0.25);
  --action-btn-outline-tertiary-border-hover-color: rgba(var(--base-accent-rgb), 0.15);
  --action-btn-outline-tertiary-border-pressed-color: rgba(var(--base-accent-rgb), 0.15);

  --error-btn-outline-primary-color: #fff;
  --error-btn-outline-primary-bg-color: #ff1a1a;
  --error-btn-outline-primary-bg-hover-color: #d40000;
  --error-btn-outline-primary-bg-pressed-color: #b90000;
  --error-btn-outline-primary-border-color: #ff1a1a;
  --error-btn-outline-primary-border-hover-color: #d40000;
  --error-btn-outline-primary-border-pressed-color: #b90000;

  --error-btn-outline-secondary-color: #ff1a1a;
  --error-btn-outline-secondary-pressed-color: #ffffff;
  --error-btn-outline-secondary-bg-color: #0d0b0b;
  --error-btn-outline-secondary-bg-hover-color: #260000;
  --error-btn-outline-secondary-bg-pressed-color: #ff1a1a;
  --error-btn-outline-secondary-border-color: #410e0e;
  --error-btn-outline-secondary-border-hover-color: #550505;
  --error-btn-outline-secondary-border-pressed-color: #b90000;

  --error-btn-outline-tertiary-color: #ff1a1a;
  --error-btn-outline-tertiary-pressed-color: #ffffff;
  --error-btn-outline-tertiary-bg-color: #00000000;
  --error-btn-outline-tertiary-bg-hover-color: #200606;
  --error-btn-outline-tertiary-bg-pressed-color: #ff1a1a;
  --error-btn-outline-tertiary-border-color: #583a3a;
  --error-btn-outline-tertiary-border-hover-color: #300e0f;
  --error-btn-outline-tertiary-border-pressed-color: #b90000;

  --btn-outline-disabled-color: rgba(255, 255, 255, 0.4);
  --btn-outline-disabled-bg-color: rgba(255, 255, 255, 0.08);
  --btn-outline-disabled-border-color: rgba(255, 255, 255, 0.1);

  --neo-input-readonly-bg: #212121;
  --neo-input-warning-bg: #332a19;
  --neo-input-danger-bg: #331c1c;

  --neo-input-danger-fg: #ff1a1a;
  --neo-input-warning-fg: #ffa500;


  --dynamic-add-button: rgba(255, 255, 255, 0.12);
  --dynamic-add-bg-button: rgba(58, 163, 255, 0.05);


  /* Scrollbar */
  --scrollbar-color: rgba(255, 255, 255, .3);
  --scrollbar-background-color: transparent;

  /* Data View */
  --dataview-header-bg-color: transparent;
  --dataview-border-color: #616161;
  --dataview-text-color: #999;
  --dataview-bg-color: #292929;
  --dataview-bg-hover-color: #333333;
  --dataview-close-icon-color: #3aa3ff;
  --dataview-close-icon-hover-bg-color: #143857;

  /* Overlay bg */
  --overlay-bg-color: rgba(66, 66, 66, 0.7);

  /* Container */
  --entry-container-bg-color: #1a1a1a;
  --entry-container-overview-bg-color: #1f1f1f;
  --dashboard-header-bg-color: #1f1f1f;
  --dashboard-data-border-color: #333;
  --dashboard-data-title-color: #999;
  --dashboard-data-main-title-color: #e0e0e0;
  --dashboard-data-subtitle-color: #999;
  --dashboard-data-text-color: #e0e0e0;
  --layout-wrapper-bg-color: #000000;
  --dashboard-card-bg-color: #1f1f1f;
  --dashboard-card-secondary-bg-color: #1f1f1f;
  --dashboard-card-border-color: #333;
  --dashboard-card-txt-color: #999;
  --dashboard-card-subtitle-color: #707070;
  --dashboard-card-title-color: #999;
  --dashboard-card-list-bg-color: #1f1f1f;
  --dashboard-card-list-bg-hover-color: #333;
  --dashboard-card-list-border-color: #3d3d3d;
  --dashboard-card-icon-color: #1F85EB;
  --dashboard-card-default-icon-color: #999;
  --dashboard-card-empty-icon-color: #525252;
  --dashboard-card-hover-background-color: rgb(0, 22, 41);
  --dashboard-card-hover-border-color: rgba(var(--base-accent-rgb), .2);

  --info-card-background-color: #00294D;
  --overlay-panel-bg-color: #333333;
  --overlay-panel-border-color: #333333;
  --overlay-mask-color: #f5f5f5;
  --page-header-bg-color: #292929;
  --layout-container-bg-color: #292929;
  --layout-container-admin-border-color: #292929;
  --layout-container-admin-shadow-color: #292929;
  --steps-container-bg-color: #1f1f1f;
  --admin-item-bg-color: #1f1f1f;
  --admin-item-bg-hover-color: #3d3d3d;
  --admin-item-bg-active-color: #525252;
  --admin-text-icon-color: #3aa3ff;
  --admin-text-icon-hover-color: #1f1f1f;
  --admin-text-hover-color: #e0e0e0;
  --admin-separator-color: #1f1f1f;
  --admin-separator-header-color: #1f1f1f;
  --admin-separator-title-color-color: #1f1f1f;
  --dashboard-expiring-icon-color: #FFA500;


  /* Tree */
  --tree-selector-bg-color: #1f1f1f;
  --tree-selector-border-color: #292929;
  --tree-selector-text-color: #999999;
  --tree-selector-text-highlight-color: #fff;
  --tree-item-selected-bg-color: #143857;
  --tree-item-hover-bg-color: #143857;
  --tree-search-input-bg-color: #141414;
  --tree-search-btn-border-color: #333;
  --restricted-access-icon-color: #525252;

  /* Inputs */
  --input-txt-border-hover-color: #00539c;
  --input-txt-border-focus-color: #3aa3ff;
  --input-txt-bg-color: #0f1420;
  --input-txt-bg-disabled-color: var(--bg-300);
  --input-txt-border-disabled-color: #333333;
  --input-txt-bg-read-only-color: rgba(var(--base-color-rgb), 0.07);
  --input-txt-color: #ffffff;
  --input-txt-read-only-color: rgba(var(--base-color-rgb), 0.80);
  --input-txt-border-color: #333333;
  --input-txt-shadow-color: transparent;
  --input-txt-success-color: #589b2c;
  --input-txt-error-color: #cb0000;


  --input-background-color: #0f1420;
  --input-border-color: rgba(var(--base-border-rgb), .3);
  --input-box-shadow: none;
  --input-accent-color: rgb(var(--base-accent-rgb));
  --input-label-color: var(--default-text-color);
  --input-selected-indicator-color: rgb(var(--base-white-rgb));
  --input-hint-color: rgba(var(--base-color-rgb), 0.6);
  --input-hint-color-important: #ff8200;

  --input-disabled-border-color: rgba(var(--base-border-rgb), .1);
  --input-disabled-label-color: rgba(var(--base-border-rgb), .3);
  --input-disabled-selected-indicator-color: rgba(var(--base-border-rgb), .3);
  --input-disabled-background-color: rgba(var(--base-border-rgb), .03);


  --input-switch-default-bg-color: #525252;
  --input-switch-active-bg-color: #3aa3ff;
  --input-switch-active-hover-bg-color: #00539c;
  --dropdown-container-bg-color: #141414;
  --dropdown-bg-color: #141414;
  --dropdown-trigger-color: #707070;
  --dropdown-filter-icon-color: #525252;
  --input-default-border-color: #333;
  --input-default-border-hover-color: #00539c;
  --dropdown-item-selected-bg-color: #163958;
  --dropdown-item-bg-color: #141414;
  --dropdown-item-selected-txt-color: #3aa3ff;
  --dropdown-item-selected-bg-hover-color: #1f1f1f;
  --dropdown-item-txt-color: #fff;
  --dropdown-user-group-selected-bg-hover-color: #1f1f1f;
  --dropdown-filter-container-separator-color: #333333;
  --dropdown-overlay-border-color: #3aa3ff;
  --input-txt-placeholder: #525252;
  --input-txt-border-error-color: #f20000;
  --paginator-active-bg-color: #3aa3ff;

  /* Chips */
  --input-chips-bg-color: rgba(var(--base-color-rgb), .08);
  --input-chips-bg-hover-color: rgba(var(--base-color-rgb), .12);
  --input-chips-bg-pressed-color: rgba(var(--base-color-rgb), .24);
  --input-chips-txt-color: var(--base-color-rgb);
  --input-chips-txt-hover-color: var(--base-color-rgb);
  --input-chips-icon-color: rgba(var(--base-color-rgb), .3);
  --input-chips-icon-hover-color: rgba(var(--base-color-rgb), 0.6);

  /* Labels */
  --default-text-color: #d2d2d2;
  --admin-title-color: #3aa3ff;
  --admin-header-color: #3aa3ff;
  --disabled-text-color: #525252;
  --hint-text-color: #707070;
  --secondary-text-color: #ffffff;
  --form-text-color: #707070;
  --active-tab-text-color: #3aa3ff;
  --menu-panel-txt-color: #999;
  --lighter-default-text-color: #797979;
  --default-header-documentation-color: #3aa3ff;
  --secondary-label-text-color: #707070;

  /* Grids */
  --grid-border-color: #464646;
  --grid-header-bg-color: #181818;
  --grid-header-title-txt-color: #999999;
  --grid-main-row-bg-color: #292929;
  --grid-child-row-bg-color: #1f1f1f;
  --grid-disabled-row-bg-color: #1a1a1a;
  --grid-disabled-txt-color: #b8b8b8;
  --grid-item-border-color: #3d3d3d;
  --grid-icon-color: #999999;
  --grid-icon-hover-color-color: #3aa3ff;
  --grid-row-hover-bg-color: #141414;
  --grid-txt-color: #999;
  --grid-container-bg-color: #292929;

  /* Messages */
  --message-font-color: #e0e0e0;
  --message-status-font-color: rgba(255, 255, 255, .6);
  --message-box-selected-rgb-color: 58, 163, 255;
  --message-box-selected-border-color: rgb(var(--message-box-selected-rgb-color));
  --message-box-selected-bg-color: rgba(var(--message-box-selected-rgb-color), .08);
  --info-message-background-color: #00539c;
  --info-message-border-color: #3aa3ff;
  --success-message-background-color: #2d4e16;
  --success-message-border-color: #6ab934;
  --warning-message-background-color: #725f00;
  --warning-message-border-color: #fbd100;
  --error-message-background-color: #7c0000;
  --error-message-border-color: #f20000;
  --status-message-background-color: #763c00;
  --status-message-border-color: #eb7800;
  --unread-message-border-color: #0e7ddf;
  --unread-message-hover-border-color: #707070;
  --unread-message-background-color: #214266;
  --disabled-message-border-color: #e0e0e0;
  --disabled-message-background-color: #707070;
  // --archived-message-border-color: #8b4513;

  /* Data Breach */
  --info-data-breach-verification-icon-color: #3aa3ff;
  --success-data-breach-verification-icon-color: #6ab934;
  --failed-data-breach-verification-icon-color: #f20000;

  /* Horizontal Line */
  --horizontal-line-color: rgba(255, 255, 255, 0.05);

  /* DropZone */
  --dropzone-bg-color: #0f2a42;
  --dropzone-border-color: #00539c;
  --dropzone-icon-color: #2973b3;
  --dropzone-text-color: #e0e0e0;
  --dropzone-border-dragover-color: #3aa3ff;
  --dropzone-icon-dragover-color: #3aa3ff;
  --dropzone-text-dragover-color: #ffffff;
  --dropzone-bg-file-uploaded-color: #1f1f1f;
  --dropzone-border-file-uploaded-color: #333333;

  /* Tooltip & tag */
  --tooltip-bg-color: #eeeeee;
  --tooltip-txt-color: #000000;
  --tooltip-box-shadow-color: rgba(0, 0, 0, 100%);
  --tag-bg-color: #000;
  --tag-txt-color: #b8b8b8;

  /* Markdown */
  --code-bg-color: #141414;
  --pre-bg-color: #141414;

  /* TabView */
  --tab-view-hover-color: #3d3d3d7f;

  /* HR */
  --hr-color: #141414;

  /* Table */
  --tab-row-expansion-background: #000000;
  --tab-row-expansion-border: #b8b8b8;

  /* Calendar */
  --today-border-color: #b8b8b8;
  --date-bg-hover-color: #292929;
  --date-bg-focus-color: #333333;
  --date-text-focus-color: #3aa3ff;

  /* Banner */
  --info-banner-icon-color: #fff;

  /* Security - Severity Level */
  --severity-level-critical-color: #ffeeee;
  --severity-level--critical-bg: #8D0000;
  --severity-level-high-color: #C80000;
  --severity-level-high-bg: #2A1212;
  --severity-level-medium-color: #E2A300;
  --severity-level-medium-bg: #2D2000;
  --severity-level-low-color: #4BB14B;
  --severity-level-low-bg: #0D260D;
  --security-box-bg: #1C1C1C;
  --security-box-title: #fff;
  --security-box-action-bg: #0C2944;
  --security-box-action-color: #88C8FF;
  --security-box-border-color: rgba(255, 255, 255, .1);
  --security-chart-progress: #00CF00;
  --security-chart-remaining: #DBDBDB;

  /* Gateway connection Active - Closed */
  --gateway-active-color: #00CF00;
  --gateway-closed-color: #ff1a1a;

  /* Tiered menu */
  --tiered-menu-bg-color: #141414;
  --tiered-menu-menuitem-bg-hover-color: #1f1f1f;

  /* User Tags */
  --user-tag-external-color: #a1b807;
  --user-tag-external-bg-color: #2e3217;
  --user-tag-privileged-color: #bc9406;
  --user-tag-privileged-bg-color: #3a3217;

  /* FIGMA */
/* rgba(158, 158, 158, 1) */
  --neutral-color-dark-values: 255, 255, 255;
  --neutral-color-dark: rgb(var(--neutral-color-dark-values));
  --text-accent-color: rgba(var(--neutral-color-dark-values), 1);
  --text-primary-color: rgba(var(--neutral-color-dark-values), 0.8);
  --text-tertiary-color: rgba(var(--neutral-color-dark-values), 0.4);

  --border-secondary-color: rgba(var(--neutral-color-dark-values), 0.12);

  --bg-primary-color: rgba(30, 31, 36, 1);
  --bg-secondary-color: #1a1a1a;

  /* Gateway surface tokens */
  --gateway-workspace-background-color: var(--main-body-bg);
  --gateway-session-background-color: var(--main-body-bg);
  --gateway-panel-background-color: #161b26;
  --gateway-panel-border-color: #2f3441;
  --gateway-panel-shadow: none;
  --gateway-panel-hover-background-color: #1c222e;
  --gateway-sidebar-border-width: 1px;
}
