:root {
  --base-black-rgb: 0, 0, 0; // #000
  --base-accent-rgb: 0, 104, 195; // #0068c3
  --base-white-rgb: 255, 255, 255; // #fff
  --base-color-rgb: var(--base-black-rgb);
  --base-color-inverted-rgb: var(--base-white-rgb);

  --title-color: rgba(var(--base-color-rgb), .8);

  --base-border-rgb: var(--base-color-rgb);

  --accent-color: rgb(var(--base-accent-rgb));

  --entry-layout-horizontal-padding: 15px;

  --btn-icon-color: rgba(var(--base-color-rgb), .8);

  --entry-status-color: rgba(var(--base-color-rgb), .6); // Default
  --entry-status-background-opacity: 1;
  --entry-status-by-me-color-rgb: 97, 170, 48;
  --entry-status-by-others-color-rgb: 255, 26, 26;
  --entry-status-flag-expired-color-rgb: var(--entry-status-by-others-color-rgb);
  --entry-status-flag-archived-color-rgb: 139, 69, 19;
  --entry-status-flag-warning-color-rgb: 0, 104, 195;
  --entry-status-flag-broken-color-rgb: 245, 208, 0;
  --entry-status-flag-locked-color-rgb: 255, 130, 0;
  --entry-status-flag-disabled-color-rgb: 153, 153, 153;

  --status-banner-info-color-rgb: 0, 104, 195;
  --status-banner-warning-color-rgb: 240, 201, 9;
  --status-banner-pending-color-rgb: 255, 142, 38;
  --status-banner-success-color-rgb: 97, 170, 48;
  --status-banner-disabled-color-rgb: 184, 184, 184;
  --status-banner-error-color-rgb: 255, 26, 26;
  --status-banner-neutral-color-rgb: 0, 0, 0;
  --status-banner-background-opacity: .25;

  --font-open-sans: 'Open Sans', sans-serif;
  --font-roboto: 'Roboto', sans-serif;
  --border-radius: 4px;

  --blue-primary: #0068c3;
  --blue-900: #003e75;
  --blue-800: #00539c;
  --blue-700: #0068c3;
  --blue-500: #1f85eb;
  --blue-300: #88c8ff;

  --red-primary: #ff1a1a;
  --red-900: #b70000;
  --red-800: #de0000;
  --red-700: #ff1a1a;
  --red-500: #ff6868;
  --red-300: #ffb7b7;

  --green-primary: #61aa30;
  --green-900: #2d4e16;
  --green-800: #508b27;
  --green-700: #61aa30;
  --green-500: #7ecc49;
  --green-300: #caecb4;

  --yellow-primary: #f0c909;
  --yellow-900: #725f00;
  --yellow-800: #946200;
  --yellow-700: #f0c909;
  --yellow-500: #ffda23;
  --yellow-300: #fff5c0;

  --orange-primary: #ff8200;
  --orange-900: #763c00;
  --orange-800: #eb7800;
  --orange-700: #ff8200;
  --orange-500: #ffa500;
  --orange-300: #ffcf9d;

  --grey-primary: #424242;
  --grey-900: #212121;
  --grey-800: #333333;
  --grey-700: #525252;
  --grey-600: #707070;
  --grey-500: #999999;
  --grey-400: #b8b8b8;
  --grey-300: #bdbdbd;
  --grey-200: #e0e0e0;
  --grey-100: #f5f5f5;
  --grey-0: #ffffff;
}
