var s=Object.defineProperty,t=Object.defineProperties;var u=Object.getOwnPropertyDescriptors;var l=Object.getOwnPropertySymbols;var p=Object.prototype.hasOwnProperty,q=Object.prototype.propertyIsEnumerable;var v=(a,b)=>(b=Symbol[a])?b:Symbol.for("Symbol."+a);var o=(a,b,c)=>b in a?s(a,b,{enumerable:!0,configurable:!0,writable:!0,value:c}):a[b]=c,x=(a,b)=>{for(var c in b||={})p.call(b,c)&&o(a,c,b[c]);if(l)for(var c of l(b))q.call(b,c)&&o(a,c,b[c]);return a},y=(a,b)=>t(a,u(b));var z=(a,b)=>{var c={};for(var d in a)p.call(a,d)&&b.indexOf(d)<0&&(c[d]=a[d]);if(a!=null&&l)for(var d of l(a))b.indexOf(d)<0&&q.call(a,d)&&(c[d]=a[d]);return c};var A=(a,b,c)=>new Promise((d,j)=>{var k=e=>{try{f(c.next(e))}catch(g){j(g)}},h=e=>{try{f(c.throw(e))}catch(g){j(g)}},f=e=>e.done?d(e.value):Promise.resolve(e.value).then(k,h);f((c=c.apply(a,b)).next())}),w=function(a,b){this[0]=a,this[1]=b},B=(a,b,c)=>{var d=(h,f,e,g)=>{try{var m=c[h](f),n=(f=m.value)instanceof w,r=m.done;Promise.resolve(n?f[0]:f).then(i=>n?d(h==="return"?h:"next",f[1]?{done:i.done,value:i.value}:i,e,g):e({value:i,done:r})).catch(i=>d("throw",i,e,g))}catch(i){g(i)}},j=h=>k[h]=f=>new Promise((e,g)=>d(h,f,e,g)),k={};return c=c.apply(a,b),k[v("asyncIterator")]=()=>k,j("next"),j("throw"),j("return"),k};export{x as a,y as b,z as c,A as d,w as e,B as f};
